package ru.myitschool.work.ui.login;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.text.Editable;
import android.view.View;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;
import androidx.lifecycle.ViewModelProvider;

import com.example.myapplication.core.SettingConstants;
import com.google.android.material.snackbar.Snackbar;
import com.google.android.material.textfield.TextInputEditText;

import ru.myitschool.work.R;
import ru.myitschool.work.databinding.ActivityLoginBinding;
import ru.myitschool.work.ui.main.MainActivity;

public class LoginActivity extends AppCompatActivity {

    private ActivityLoginBinding binding;
    private LoginViewModel viewModel;


    public LoginActivity() {
        super(R.layout.activity_login);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_login);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;

            binding = ActivityLoginBinding.bind(v);
            viewModel = new ViewModelProvider(this).get(LoginViewModel.class);

            binding.email.addTextChangedListener(new TextChangedListener<>(binding.email) {
                @Override
                public void onTextChanged(TextInputEditText target, Editable s) {
                    listenerEmailEditText(s);
                }
            });

            binding.password.addTextChangedListener(new TextChangedListener<>(binding.password) {
                @Override
                public void onTextChanged(TextInputEditText target, Editable s) {
                    listenerPasswordEditText(s);
                }
            });

            binding.btEnter.setOnClickListener(this::onClickListenerLoginButton);

            subscribe();
        });
    }

        private void subscribe() {
            viewModel.errorLiveData.observe(this, error -> {
                binding.btEnter.setEnabled(true);
                Snackbar.make(findViewById(android.R.id.content), error, Snackbar.LENGTH_LONG).show();
            });
            viewModel.openLiveData.observe(this, employee -> {
                binding.btEnter.setEnabled(true);

                SharedPreferences settings = this.getSharedPreferences(
                        SettingConstants.PREFS_FILE, Context.MODE_PRIVATE
                );
                settings.edit().putLong(SettingConstants.PREF_ID, employee.getId()).apply();
                settings.edit().putString(SettingConstants.PREF_ROLE, employee.getRole()).apply();

                startActivity(new Intent(getApplicationContext(), MainActivity.class));
            });
        }

        private void listenerEmailEditText(Editable s) {
            if (s.toString().isEmpty()) {
                binding.email.setError("Обязательное поле");
            } else if (!isEmailValid(s.toString())) {
                binding.emailLay.setError("Неверный формат");
            } else {
                binding.emailLay.setErrorEnabled(false);
            }
        }

        private void listenerPasswordEditText(Editable s) {
            if (s.toString().isEmpty()) {
                binding.passwordLay.setError("Обязательное поле");
            } else {
                binding.passwordLay.setErrorEnabled(false);
            }
        }

        private void onClickListenerLoginButton(View view) {
            binding.btEnter.setEnabled(false);

            viewModel.changeEmail(String.valueOf(binding.email.getText()));
            viewModel.changePassword(String.valueOf(binding.password.getText()));
            viewModel.confirm();
        }

        private boolean isEmailValid(String email) {
            return android.util.Patterns.EMAIL_ADDRESS.matcher(email).matches();
        }
}